RemoteControllerIdentifierPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • RemoteControllerIdentifierPlatform
Implementers

Constructors

RemoteControllerIdentifierPlatform()
Constructs a RemoteControllerIdentifierPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPackageInfo(dynamic packageNames) → Future<Map>
getPlatformVersion() → Future<String?>
getScreenMirroring() → Future<bool?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ RemoteControllerIdentifierPlatform
The default instance of RemoteControllerIdentifierPlatform to use.
getter/setter pair